package com.ruoyi.system.service.impl.fgw;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.fgw.FgwShyj;
import com.ruoyi.system.domain.fgw.FgwXmsb;
import com.ruoyi.system.mapper.fgw.FgwShyjMapper;
import com.ruoyi.system.mapper.fgw.FgwXmsbMapper;
import com.ruoyi.system.service.fgw.IFgwShyjService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import static com.ruoyi.common.constant.CommonConstants.THR;
import static com.ruoyi.common.constant.CommonConstants.TWO;


/**
 * 发改委_审核意见Service业务层处理
 *
 * @author boman
 * @date 2023-03-22
 */
@Service
public class FgwShyjServiceImpl implements IFgwShyjService {
    @Autowired
    private FgwShyjMapper fgwShyjMapper;

    @Autowired
    private FgwXmsbMapper fgwXmsbMapper;

    /**
     * 查询发改委_审核意见
     *
     * @param id 发改委_审核意见主键
     * @return 发改委_审核意见
     */
    @Override
    public FgwShyj selectFgwShyjById(Long id) {
        return fgwShyjMapper.selectFgwShyjById(id);
    }

    /**
     * 查询发改委_审核意见列表
     *
     * @param fgwShyj 发改委_审核意见
     * @return 发改委_审核意见
     */
    @Override
    public List<FgwShyj> selectFgwShyjList(FgwShyj fgwShyj) {
        return fgwShyjMapper.selectFgwShyjList(fgwShyj);
    }

    /**
     * 新增发改委_审核意见
     *
     * @param fgwShyj 发改委_审核意见
     * @return 结果
     */
    @Override
    public int insertFgwShyj(FgwShyj fgwShyj) {
        fgwShyj.setCreateTime(DateUtils.getNowDate());
        fgwShyj.setDeptId(SecurityUtils.getDeptId());
        return fgwShyjMapper.insertFgwShyj(fgwShyj);
    }

    /**
     * 修改发改委_审核意见
     *
     * @param fgwShyj 发改委_审核意见
     * @return 结果
     */
    @Override
    public int updateFgwShyj(FgwShyj fgwShyj) {
        fgwShyj.setUpdateTime(DateUtils.getNowDate());
        return fgwShyjMapper.updateFgwShyj(fgwShyj);
    }

    /**
     * 批量删除发改委_审核意见
     *
     * @param ids 需要删除的发改委_审核意见主键
     * @return 结果
     */
    @Override
    public int deleteFgwShyjByIds(Long[] ids) {
        return fgwShyjMapper.deleteFgwShyjByIds(ids);
    }

    /**
     * 删除发改委_审核意见信息
     *
     * @param id 发改委_审核意见主键
     * @return 结果
     */
    @Override
    public int deleteFgwShyjById(Long id) {
        return fgwShyjMapper.deleteFgwShyjById(id);
    }

    /**
     * 发改委审核
     *
     * @param fgwShyj
     * @return
     */
    @Override
    public AjaxResult xssh(FgwShyj fgwShyj) {
        //获取审核意见
        String shjg = fgwShyj.getShjg();
        //查询项目当前状态
        FgwXmsb fgwXmsb = fgwXmsbMapper.selectFgwXmsbById(fgwShyj.getXmId());
        if (TWO.equals(fgwXmsb.getStatus())) {
            return AjaxResult.error("当前项目已审核");
        }
        if (TWO.equals(shjg)) {
            //审核通过修改项目状态
            fgwXmsb.setStatus(TWO);
            fgwXmsb.setType(TWO);
        } else if (THR.equals(shjg)) {
            fgwXmsb.setStatus(THR);
        }
        //修改主表状态
        fgwXmsbMapper.updateFgwXmsbStatus(fgwXmsb);
        fgwShyj.setCreateTime(DateUtils.getNowDate());
        fgwShyj.setDeptId(SecurityUtils.getDeptId());
        fgwShyj.setShrxm(SecurityUtils.getUsername());
        fgwShyj.setShsj(DateUtils.getNowDate());
        fgwShyjMapper.insertFgwShyj(fgwShyj);
        return AjaxResult.success();
    }
}
