package com.ruoyi.system.service.impl.fgw;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.fgw.FgwDbd;
import com.ruoyi.system.domain.fgw.FgwFj;
import com.ruoyi.system.domain.fgw.FgwXmsb;
import com.ruoyi.system.domain.projectV2.ZsyzSbbzb;
import com.ruoyi.system.mapper.fgw.FgwDbdMapper;
import com.ruoyi.system.mapper.fgw.FgwFjMapper;
import com.ruoyi.system.mapper.fgw.FgwXmsbMapper;
import com.ruoyi.system.service.fgw.IFgwXmsbService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import static com.ruoyi.common.constant.CommonConstants.ONE;
import static com.ruoyi.common.constant.CommonConstants.TWO;


/**
 * 发改委_申报_主Service业务层处理
 * 
 * @author boman
 * @date 2023-03-22
 */
@Service
public class FgwXmsbServiceImpl implements IFgwXmsbService
{
    @Autowired
    private FgwXmsbMapper fgwXmsbMapper;
    @Autowired
    private FgwFjMapper fgwFjMapper;
    @Autowired
    private FgwDbdMapper fgwDbdMapper;

    /**
     * 查询发改委_申报_主
     * 
     * @param id 发改委_申报_主主键
     * @return 发改委_申报_主
     */
    @Override
    public FgwXmsb selectFgwXmsbById(Long id)
    {
        FgwXmsb fgwXmsb = fgwXmsbMapper.selectFgwXmsbById(id);
        List<FgwFj> fgwFjs = fgwFjMapper.selectFgwFjByXmId(fgwXmsb.getId());
        if (fgwFjs != null && fgwFjs.size() > 0){
            fgwXmsb.setFjList(fgwFjs);
        }
        return fgwXmsb;

    }

    /**
     * 查询发改委_申报_主列表
     * 
     * @param fgwXmsb 发改委_申报_主
     * @return 发改委_申报_主
     */
    @Override
    public List<FgwXmsb> selectFgwXmsbList(FgwXmsb fgwXmsb)
    {
        return fgwXmsbMapper.selectFgwXmsbList(fgwXmsb);
    }

    /**
     * 统计合格项目
     * @param fgwXmsb
     * @return
     */
    @Override
    public List<FgwXmsb> selectFgwXmsbListTj(FgwXmsb fgwXmsb) {
        fgwXmsbMapper.selectFgwXmsbListTj(fgwXmsb);
        return null;
    }

    /**
     * 新增发改委_申报_主
     * 
     * @param fgwXmsb 发改委_申报_主
     * @return 结果
     */
    @Override
    public int insertFgwXmsb(FgwXmsb fgwXmsb)
    {
        fgwXmsb.setCreateTime(DateUtils.getNowDate());
        return fgwXmsbMapper.insertFgwXmsb(fgwXmsb);
    }

    /**
     * 修改发改委_申报_主
     * 
     * @param fgwXmsb 发改委_申报_主
     * @return 结果
     */
    @Override
    public int updateFgwXmsb(FgwXmsb fgwXmsb)
    {
        fgwXmsb.setUpdateTime(DateUtils.getNowDate());
        String progress = fgwXmsb.getProgress();
        String status = fgwXmsb.getStatus();
        if (ONE.equals(progress) && TWO.equals(status)){
            //修改主表项目进入前期工作手续 待审核
            fgwXmsb.setProgress(TWO);
            fgwXmsb.setStatus(ONE);
        }
        //修改主表项目进入待审核
        fgwXmsb.setStatus(ONE);
        List<FgwFj> fjList = fgwXmsb.getFjList();
        //删除之前的
        fgwFjMapper.deleteFgwFjByXmId(fgwXmsb.getId(),1L);
        if (fjList != null && fjList.size() > 0){
            //保存当前的
            for (FgwFj fgwFj : fjList) {
                fgwFjMapper.insertFgwFj(fgwFj);
                //修改督办的状态
                fgwDbdMapper.updateFgwDbdByDbnrId(fgwXmsb.getId(),fgwFj.getType());

            }

        }
        return fgwXmsbMapper.updateFgwXmsb(fgwXmsb);
    }

    /**
     * 批量删除发改委_申报_主
     * 
     * @param ids 需要删除的发改委_申报_主主键
     * @return 结果
     */
    @Override
    public int deleteFgwXmsbByIds(Long[] ids)
    {
        return fgwXmsbMapper.deleteFgwXmsbByIds(ids);
    }

    /**
     * 删除发改委_申报_主信息
     * 
     * @param id 发改委_申报_主主键
     * @return 结果
     */
    @Override
    public int deleteFgwXmsbById(Long id)
    {
        return fgwXmsbMapper.deleteFgwXmsbById(id);
    }

    @Override
    public List<FgwXmsb> ldpsList(FgwXmsb fgwXmsb) {
        return fgwXmsbMapper.ldpsList(fgwXmsb);
    }

    @Override
    public AjaxResult selectFgwXmsbListAll(FgwXmsb fgwXmsb) {
        Map<String,Integer> map = new HashMap<>();
        map.put("all",0);
        map.put("sbk",0);
        map.put("xmk",0);
        List<FgwXmsb> fgwXmsbList = fgwXmsbMapper.selectFgwXmsbListAll(fgwXmsb);
        Map<String, List<FgwXmsb>> fgwXmsbMap = fgwXmsbList.stream().collect(Collectors.groupingBy(FgwXmsb::getType));
        if(fgwXmsbList!=null && fgwXmsbList.size()>0){
            map.put("all",fgwXmsbList.size());
        }
        if(fgwXmsbMap.get("1")!=null && fgwXmsbMap.get("1").size()>0){
            map.put("sbk",fgwXmsbMap.get("1").size());
        }
        if(fgwXmsbMap.get("2")!=null && fgwXmsbMap.get("2").size()>0){
            map.put("xmk",fgwXmsbMap.get("2").size());
        }

        return AjaxResult.success(map);
    }
}
